
CREATE TABLE IF NOT EXISTS 'ContainerItem'(
'key' integer primary key autoincrement not null ,
'identifier' varchar(1024) ,
'type' varchar(200) ,
'title' varchar(200) ,
'titleDirty' integer DEFAULT 0,
'url' varchar(320) ,
'description' varchar(200) ,
'lastUpdated' datetime ,
'sortIdentifier' varchar(100),
'unsubscribed' integer DEFAULT 0,
'added' integer DEFAULT 0
);

CREATE INDEX IF NOT EXISTS 'ContainerItem_Type' on 'ContainerItem'('type');



CREATE TABLE IF NOT EXISTS 'FeedItem'(
'key' integer primary key autoincrement not null ,
'title' varchar(200) ,
'identifier' varchar(1024) ,
'identifierHash' integer,
'date' datetime ,
'description' text ,
'url' varchar(1024) ,
'creator' varchar(200) ,
'commentUrl' nvarchar(1024),
'commentCount' integer ,
'parent' integer CONSTRAINT fk_FeedItem_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE
 );

CREATE INDEX IF NOT EXISTS 'FeedItem_Parent' on 'FeedItem'('parent', 'date' desc);
CREATE INDEX IF NOT EXISTS 'FeedItem_Date' on 'FeedItem'('date');
CREATE INDEX IF NOT EXISTS 'FeedItem_IdentifierHash' on 'FeedItem'('identifierHash');



CREATE TABLE IF NOT EXISTS 'Setting'(
'key' integer primary key autoincrement not null ,
'name' varchar(200) unique,
'value' text );


CREATE TABLE IF NOT EXISTS 'SmartFeed'(
'key' integer primary key autoincrement not null ,
'identifier' varchar(1024) ,
'type' varchar(200) ,
'title' varchar(200) ,
'keywords' varchar(200),
'parent' integer,
'sort' varchar(100)
);



CREATE TABLE IF NOT EXISTS 'ContainerItemFolder'(
'key' integer primary key autoincrement not null ,
'parent' integer CONSTRAINT fk_ContainerItemFolder_parent REFERENCES ContainerItem(key),
'child' integer not null CONSTRAINT fk_ContainerItemFolder_child REFERENCES ContainerItem(key),
'removed' integer DEFAULT 0,
'added' integer DEFAULT 0,
'sort' varchar(100),
'sortDirty' integer NOT NULL DEFAULT 0
 );
 
CREATE INDEX IF NOT EXISTS 'ContainerItemFolder_ChildSort' on 'ContainerItemFolder'('child', 'removed', 'sort');
CREATE INDEX IF NOT EXISTS 'ContainerItemFolder_Parent' on 'ContainerItemFolder'('parent');


DROP VIEW IF EXISTS 'ContainerItemView';
CREATE VIEW IF NOT EXISTS 'ContainerItemView' AS 
	SELECT
		CI.*,
		CIF.parent,
		CIF.sort,
		CIF.sortDirty,
		CIF.key folder
	FROM
		ContainerItem CI 
		LEFT OUTER JOIN ContainerItemFolder CIF ON (CI.key = CIF.child AND CIF.removed=0);



CREATE TABLE IF NOT EXISTS 'FeedItemRead'(
'key' integer NOT NULL,
'parent' integer CONSTRAINT fk_FeedItemRead_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE,
'unread' integer DEFAULT 0,
'readDirty' integer DEFAULT 0
 );
 
CREATE UNIQUE INDEX IF NOT EXISTS 'FeedItemRead_KeyParent' on 'FeedItemRead'('key', 'parent');
CREATE INDEX IF NOT EXISTS 'FeedItemRead_ReadParent' on 'FeedItemRead'('unread', 'parent');
CREATE INDEX IF NOT EXISTS 'FeedItemRead_ReadDirty' on 'FeedItemRead'('readDirty');



CREATE TABLE IF NOT EXISTS 'FeedItemStarred'(
'key' integer NOT NULL,
'parent' integer CONSTRAINT fk_FeedItemStarred_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE,
'starred' integer DEFAULT 0,
'starredDirty' integer DEFAULT 0
 );
 
CREATE UNIQUE INDEX IF NOT EXISTS 'FeedItemStarred_KeyParent' on 'FeedItemStarred'('key', 'parent');
CREATE INDEX IF NOT EXISTS 'FeedItemStarred_StarredParent' on 'FeedItemStarred'('starred', 'parent');
CREATE INDEX IF NOT EXISTS 'FeedItemStarred_StarredDirty' on 'FeedItemStarred'('starredDirty');



CREATE VIEW IF NOT EXISTS 'FeedItemView' AS 
	SELECT
		FI.*,
		FIR.unread as unread,
		FIR.readDirty as readDirty,
		FIS.starred as starred,
		FIS.starredDirty as starredDirty
	FROM
		FeedItem FI
		LEFT OUTER JOIN FeedItemRead FIR ON (FIR.key = FI.key)
		LEFT OUTER JOIN FeedItemStarred FIS ON (FIS.key = FI.key);


PRAGMA user_version = 16;