
DROP INDEX IF EXISTS 'FeedItem_Parent';
DROP INDEX IF EXISTS 'FeedItem_Date';
DROP INDEX IF EXISTS 'FeedItem_IdentifierHash';
ALTER TABLE FeedItem RENAME TO FeedItem_old;


CREATE TABLE 'FeedItem'(
'key' integer primary key autoincrement not null ,
'parent' integer CONSTRAINT fk_FeedItem_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE,
'date' datetime ,
'identifierHash' integer,
'cachedImages' integer DEFAULT 0 NOT NULL,

'identifier' varchar(1024) ,
'title' varchar(200) ,
'url' varchar(1024) ,
'summary' varchar(100),
'creator' varchar(200)
 );

CREATE INDEX IF NOT EXISTS 'FeedItem_Parent' on 'FeedItem'('parent', 'date' desc);
CREATE INDEX IF NOT EXISTS 'FeedItem_Date' on 'FeedItem'('date');
CREATE INDEX IF NOT EXISTS 'FeedItem_IdentifierHash' on 'FeedItem'('identifierHash');

CREATE TABLE content.'FeedItemContent'(
'key' integer primary key not null,
'parent' integer CONSTRAINT fk_FeedItemContent_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE,
'content' text
);

CREATE INDEX IF NOT EXISTS content.'FeedItemContent_Parent' on 'FeedItemContent'('parent');

CREATE TABLE images.'FeedItemImage'(
'key' integer primary key autoincrement not null,
'item' integer CONSTRAINT fk_FeedItemImage_FeedItem REFERENCES FeedItem(key) ON DELETE CASCADE,
'parent' integer CONSTRAINT fk_FeedItemImage_ContainerItem REFERENCES ContainerItem(key) ON DELETE CASCADE,
'url' text,
'type' varchar(100),
'size' integer,
'data' blob
);

CREATE INDEX IF NOT EXISTS images.'FeedItemImage_FeedItem' on 'FeedItemImage'('item');
CREATE INDEX IF NOT EXISTS images.'FeedItemImage_Parent' on 'FeedItemImage'('parent');

INSERT INTO FeedItem(key, parent, date, identifierHash, identifier, title, url, summary, creator)
SELECT key, parent, date, identifierHash, identifier, title, url, summary, creator FROM FeedItem_old;

INSERT INTO FeedItemContent(key, parent, content)
SELECT key, parent, description from FeedItem_old;

DROP TABLE FeedItem_old;

VACUUM;